| Home | Libraries | People | FAQ | More

## Gamma Functions

Gamma
Log Gamma
Digamma
Trigamma
Polygamma
Ratios of Gamma Functions
Incomplete Gamma Functions
Incomplete Gamma Function Inverses
Derivative of the Incomplete Gamma Function

Copyright © 2006-2021 Nikhar Agrawal, Anton Bikineev, Matthew Borland, Paul A. Bristow, Marco Guazzone, Christopher Kormanyos, Hubert Holin, Bruno Lalande, John Maddock, Evan Miller, Jeremy Murphy, Matthew Pulver, Johan Råde, Gautam Sewani, Benjamin Sobotta, Nicholas Thompson, Thijs van den Berg, Daryle Walker and Xiaogang Zhang

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)